ledger.Movement (Movement) — amici1

# `ledger.Movement` (Movement)

Movement(id, voucher, partner, seqno, account, amount, match, cleared, value_date)

Master tables : ledger.AllMovements (Movements), ledger.Movements (Movements), ledger.MyMovements (My movements)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Voucher (voucher) : Pointer to the ledger voucher that caused this movement.

- Partner (partner) : Pointer to the partner involved in this movement.

- Seq.No. (seqno) : Sequential number within a voucher.

- Account (account) : Pointer to the Account that is being moved by this movement.

- amount (amount) : See `<lino.core.fields.PriceField: amount>`.

- Match (match) : Pointer to the Movement that is being cleared by this movement.

- Cleared (cleared) : Whether

- Value date (value_date) : The date at which this movement is to be entered into the ledger. This is usually the voucher’s entry_date, except e.g. for bank statements where each item can have its own value date.

- Debit (debit) : Virtual field showing amount if dc is DEBIT.

- Credit (credit) : Virtual field showing amount if dc is CREDIT.

- Voucher (voucher_link) : A virtual field which shows a link to the voucher.

- Voucher partner (voucher_partner) : A virtual field which returns the partner of the voucher. For incoming invoices this is the supplier, for outgoing invoices this is the customer, for financial vouchers this is empty.

- Match (match_link) : A virtual field which shows a clickable variant of the match string. Clicking it will open a table with all movements having that match.

- Name (name_column) : See `lino_xl.lib.ledger.models.Movement.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.ledger.models.Movement.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.ledger.models.Movement.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
voucher | Voucher | Pointer to the ledger voucher that caused this movement.
partner | Partner | Pointer to the partner involved in this movement.
seqno | Seq.No. | Sequential number within a voucher.
account | Account | Pointer to the Account that is being moved by this movement.
amount | amount |
match | Match | Pointer to the Movement that is being cleared by this movement.
cleared | Cleared | Whether
value_date | Value date | The date at which this movement is to be entered into the ledger. This is usually the voucher’s entry_date, except e.g. for bank statements where each item can have its own value date.
debit | Debit | Virtual field showing amount if dc is DEBIT.
credit | Credit | Virtual field showing amount if dc is CREDIT.
voucher_link | Voucher | A virtual field which shows a link to the voucher.
voucher_partner | Voucher partner | A virtual field which returns the partner of the voucher. For incoming invoices this is the supplier, for outgoing invoices this is the customer, for financial vouchers this is empty.
match_link | Match | A virtual field which shows a clickable variant of the match string. Clicking it will open a table with all movements having that match.
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |